export interface TagOptions {
  sequence: number;
  tags?: Array<string>;
}
export interface AliasOptions {
  sequence: number;
  alias?: string;
}
import { Injectable } from '@angular/core';
import {
  Plugin,
  Cordova,
  CordovaProperty,
  CordovaInstance,
  InstanceProperty,
  AwesomeCordovaNativePlugin,
} from '@awesome-cordova-plugins/core';
import { Observable } from 'rxjs';

/**
 * @name J Push
 * @description
 * This plugin does something
 *
 * @usage
 * ```typescript
 * import { JPush } from '@awesome-cordova-plugins/j-push';
 *
 *
 * constructor(private jPush: JPush) { }
 *
 * ...
 *
 *
 * this.jPush.functionName('Hello', 123)
 *   .then((res: any) => console.log(res))
 *   .catch((error: any) => console.error(error));
 *
 * ```
 */
@Plugin({
  pluginName: 'JPush',
  plugin: 'jpush-phonegap-plugin', // npm package name, example: cordova-plugin-camera
  pluginRef: 'JPush', // the variable reference to call the plugin, example: navigator.geolocation
  repo: 'git+https://github.com/jpush/jpush-phonegap-plugin.git', // the github repository URL for the plugin
  install: 'cordova plugin add jpush-phonegap-plugin --variable APP_KEY=your_jpush_appkey', // OPTIONAL install command, in case the plugin requires variables
  installVariables: ['APP_KEY'], // OPTIONAL the plugin requires variables
  platforms: ['Android', 'iOS'], // Array of platforms supported, example: ['Android', 'iOS']
})
@Injectable()
export class JPush extends AwesomeCordovaNativePlugin {
  /**
   * This function does something
   * @param arg1 {string} Some param to configure something
   * @param arg2 {number} Another param to configure something
   * @return {Promise<any>} Returns a promise that resolves when something happens
   */
  @Cordova()
  functionName(arg1: string, arg2: number): Promise<any> {
    return; // We add return; here to avoid any IDE / Compiler errors
  }

  @Cordova()
  init(): void {}

  @Cordova()
  setDebugMode(enable: boolean): void {}
  @Cordova()
  async getRegistrationID(): Promise<any> {
    return;
  }
  @Cordova()
  async stopPush(): Promise<any> {
    return;
  }
  @Cordova()
  async resumePush(): Promise<any> {
    return;
  }
  @Cordova()
  async isPushStopped(): Promise<any> {
    return;
  }
  @Cordova()
  async setTags(params: TagOptions): Promise<any> {
    return;
  }
  @Cordova()
  async addTags(params: TagOptions): Promise<any> {
    return;
  }
  @Cordova()
  async deleteTags(params: TagOptions): Promise<any> {
    return;
  }
  @Cordova()
  async cleanTags(params: TagOptions): Promise<any> {
    return;
  }
  @Cordova()
  async getAllTags(params: TagOptions): Promise<any> {
    return;
  }
  /**
   * @param params { sequence: number, tag: string }
   */
  @Cordova()
  async checkTagBindState(params: { sequence: number; tag: string }): Promise<any> {
    return;
  }
  @Cordova()
  async setAlias(params: AliasOptions): Promise<any> {
    return;
  }
  @Cordova()
  async deleteAlias(params: AliasOptions): Promise<any> {
    return;
  }
  @Cordova()
  async getAlias(params: AliasOptions): Promise<any> {
    return;
  }
  /**
   * Determinate whether the application notification has been opened.
   *
   * iOS: 0: closed; >1: opened.
   *  UIRemoteNotificationTypeNone = 0,
   *  UIRemoteNotificationTypeBadge = 1 << 0,
   *  UIRemoteNotificationTypeSound = 1 << 1,
   *  UIRemoteNotificationTypeAlert = 1 << 2,
   *  UIRemoteNotificationTypeNewsstandContentAvailability = 1 << 3
   *
   * Android: 0: closed; 1: opened.
   */
  @Cordova()
  async getUserNotificationSettings(): Promise<any> {
    return;
  }
  @Cordova()
  async clearLocalNotifications(): Promise<any> {
    return;
  }
  @Cordova()
  setBadge(badge: number): void {}
  @Cordova()
  resetBadge(): void {}
  @Cordova()
  setApplicationIconBadgeNumber(badge: number): void {}
  @Cordova()
  async getApplicationIconBadgeNumber(): Promise<any> {
    return;
  }
  @Cordova()
  addLocalNotificationForIOS(
    delayTime: number,
    content: string,
    badge: number,
    identifierKey: string,
    extras?: object
  ): void {}
  @Cordova()
  deleteLocalNotificationWithIdentifierKeyInIOS(identifierKey: string): void {}
  @Cordova()
  addDismissActions(actions: Array<object>, categoryId: string): void {}
  @Cordova()
  addNotificationActions(actions: Array<object>, categoryId: string): void {}
  @Cordova()
  setLocation(latitude: number, longitude: number): void {}
  @Cordova()
  startLogPageView(pageName: string): void {}
  @Cordova()
  stopLogPageView(pageName: string): void {}
  @Cordova()
  beginLogPageView(pageName: string, duration: number): void {}
  @Cordova()
  async getConnectionState(): Promise<any> {
    return;
  }
  @Cordova()
  async setBasicPushNotificationBuilder(): Promise<any> {
    return;
  }
  @Cordova()
  async setCustomPushNotificationBuilder(): Promise<any> {
    return;
  }
  @Cordova()
  async clearAllNotification(): Promise<any> {
    return;
  }
  @Cordova()
  async clearNotificationById(id: number): Promise<any> {
    return;
  }
  @Cordova()
  async setLatestNotificationNum(num: number): Promise<any> {
    return;
  }
  @Cordova()
  async addLocalNotification(
    builderId: number,
    content: string,
    title: string,
    notificationId: number,
    broadcastTime: number,
    extras?: string
  ): Promise<any> {
    return;
  }
  @Cordova()
  async removeLocalNotification(notificationId: number): Promise<any> {
    return;
  }
  @Cordova()
  async reportNotificationOpened(msgId: number): Promise<any> {
    return;
  }
  @Cordova()
  async requestPermission(): Promise<any> {
    return;
  }
  @Cordova()
  async setSilenceTime(startHour: number, startMinute: number, endHour: number, endMinute: number): Promise<any> {
    return;
  }
  @Cordova()
  async setPushTime(weekdays: Array<string>, startHour: number, endHour: number): Promise<any> {
    return;
  }
}
